@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 ### after: use lib qw(@RT_LIB_PATH@);
-use lib qw(/Users/jbrandt/rts/rt440-test/local/lib /Users/jbrandt/rts/rt440-test/lib);
+use lib qw(/opt/rt4/local/lib /opt/rt4/lib);
 
 package RT::Extension::MandatoryOnTransition::Test;
 
@@ -36,8 +36,9 @@ Set( %MandatoryOnTransition,
         'open -> resolved' => [qw(TimeWorked TimeTaken)]
     },
     'General' => {
-        '* -> resolved' => ['TimeWorked', 'TimeTaken', 'CF.Test Field']
-    },
+        '* -> resolved' => ['TimeWorked', 'TimeTaken', 'CF.Test Field', 'CF.Test Field3', 'CF.Test Field4'],
+        'CF.Test Field3' => { transition => '* -> resolved', must_be => ['normal', 'restored'] },
+        'CF.Test Field4' => { transition => '* -> resolved', must_not_be => ['down', 'reduced'] } },
 );
 CONFIG
 
